Skip to contents

Returns the first n time points from a simulate_affectOU object.

Usage

# S3 method for class 'simulate_affectOU'
head(x, n = 6L, ...)

Arguments

x

A simulate_affectOU simulation object

n

Number of time points to keep from the start (default 6)

...

Additional arguments passed to utils::head()

Value

A simulation data.frame truncated to the first n time points.

Examples

model <- affectOU()
sim <- simulate(model)
head(sim)
#>   time dim sim      value
#> 1 0.00   1   1 -0.7746211
#> 2 0.01   1   1 -0.7094374
#> 3 0.02   1   1 -0.5771827
#> 4 0.03   1   1 -0.5577653
#> 5 0.04   1   1 -0.5392849
#> 6 0.05   1   1 -0.4910150